package com.xkrs.controller;

import com.xkrs.dao.DataSourceDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.entity.DataSource;
import com.xkrs.model.qo.DataSourceQo;
import com.xkrs.service.DataSourceService;
import com.xkrs.util.DataSourceQuery;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/19 17:05
 */
@RestController
public class DataSourceController {

    @Resource
    private DataSourceService dataSourceService;

    @Resource
    private DataSourceQuery dataSourceQuery;

    @Resource
    private DataSourceDao dataSourceDao;

    /**
     * 添加测量数据
     *
     * @param dataSourceQo
     * @return
     */
    @PostMapping("/insertDataSource")
    public String insertDataSource(@RequestBody DataSourceQo dataSourceQo) {
        return dataSourceService.insertDataSource(dataSourceQo);
    }

    /**
     * 查询某一产品的测量信息
     *
     * @param lotNo      批次号
     * @param machineNo  机器号
     * @param materialNo 物料号
     * @param modelNo    模具号
     * @param partNo     零件号
     * @return
     */
    @GetMapping("/selectDataSource")
    public String selectDataSource(@RequestParam(required = false, value = "lotNo") String lotNo,
                                   @RequestParam(required = false, value = "machineNo") String machineNo,
                                   @RequestParam(required = false, value = "materialNo") String materialNo,
                                   @RequestParam(required = false, value = "modelNo") String modelNo,
                                   @RequestParam(required = false, value = "partNo") String partNo) {
        Locale locale = LocaleContextHolder.getLocale();
        List<DataSource> dataSources = dataSourceQuery.selectDataSource(lotNo, machineNo, materialNo, modelNo, partNo);
        if (dataSources == null || dataSources.size() == 0) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该产品的测量信息！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, dataSources, locale);
    }

    /**
     * 查询全部的测量信息
     *
     * @return
     */
    @GetMapping("/selectAllSource")
    public String selectAllSource() {
        Locale locale = LocaleContextHolder.getLocale();
        List<DataSource> dataSources = dataSourceDao.findAll();
        if (dataSources.size() == 0) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该产品的测量信息！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, dataSources, locale);
    }
}
